@@ -9,7 +9,7 @@ use SUPER;
 
 # ABSTRACT: ECMAScript-262, Edition 5, string numeric literal grammar written in Marpa BNF
 
-our $VERSION = '0.009'; # TRIAL VERSION
+our $VERSION = '0.010'; # TRIAL VERSION
 
 
 #
@@ -158,7 +158,7 @@ MarpaX::Languages::ECMAScript::AST::Grammar::ECMAScript_262_5::StringNumericLite
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -202,6 +202,10 @@ Returns option for Marpa::R2::Scanless::R->new(), returned as a reference to a h
 
 L<Data::Float>
 
+L<Scalar::Util::Numeric>
+
+L<Math::BigFloat>
+
 L<MarpaX::Languages::ECMAScript::AST::Grammar::ECMAScript_262_5::Base>
 
 L<MarpaX::Languages::ECMAScript::AST::Grammar::ECMAScript_262_5::StringNumericLiteral::NativeNumberSemantics>
